# Fixed Examples

Thsi directory contains fully-independed examples for the ISAAC-Toolkit. Any input artifacts (ELFs, Traces,...) are part of the repository, which means that no extra tools needs to be installed/downloaded. These artifacts can also be used for unit/integration tests in the future.

#### Programs

See subdirectories! (Coremark, Dhrystone,...)

## Prerequisites

(Hopefully) none...